@@ -8,11 +8,12 @@ from learning_loop_node.trainer.trainer import Trainer
 from learning_loop_node.context import Context
 from learning_loop_node.trainer.downloader_factory import DownloaderFactory
 from learning_loop_node.annotation_node.annotation_tool import AnnotationTool
-from learning_loop_node.annotation_node.data_classes import EventType,UserInput
+from learning_loop_node.annotation_node.data_classes import EventType, UserInput
 
 
 class AnnotationNode(Node):
     tool: AnnotationTool
+    histories: dict = {}
 
     def __init__(self, name: str, uuid: str, tool: AnnotationTool):
         super().__init__(name, uuid)
@@ -23,17 +24,26 @@ class AnnotationNode(Node):
             return await self.handle_user_input(organization, project, user_input)
 
     async def handle_user_input(self, organization, project, user_input) -> str:
+        raise Exception('Test Drone build')
         ic(user_input)
+
         input = UserInput.parse_obj(user_input)
         await self.download_image(input.data.context, input.data.image_uuid)
-        tool_result = await self.tool.handle_user_input(input)
+        history = self.get_history(input.frontend_id)
+        tool_result = await self.tool.handle_user_input(input, history)
         ic(tool_result)
         if tool_result.annotation:
             result = await self.sio_client.call('update_segmentation_annotation', (organization,
-                                                                               project, jsonable_encoder(tool_result.annotation)), timeout=2)
+                                                                                   project, jsonable_encoder(tool_result.annotation)), timeout=2)
 
         return tool_result.svg
 
+    def get_history(self, frontend_id: str) -> dict:
+        if not frontend_id in self.histories.keys():
+            self.histories[frontend_id] = self.tool.create_empty_history()
+
+        return self.histories[frontend_id]
+
     async def send_status(self):
         status = AnnotationNodeStatus(
             id=self.uuid,
@@ -52,4 +62,4 @@ class AnnotationNode(Node):
         images_folder = Trainer.create_image_folder(project_folder)
 
         downloader = DownloaderFactory.create(context=context)
-        await downloader.download_images([uuid], images_folder)
\ No newline at end of file
+        await downloader.download_images([uuid], images_folder)
