@@ -2,7 +2,9 @@
 import psutil
 import os
 import subprocess
+import signal
 from icecream import ic
+import logging
 
 
 class Executor:
@@ -13,13 +15,13 @@ class Executor:
         self.process = None
 
     def start(self, cmd: str):
-        # NOTE we have to write the pid inside the bash command to get the correct pid.
         self.process = subprocess.Popen(
             f'cd {self.path}; {cmd} >> last_training.log 2>&1',
             shell=True,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             executable='/bin/bash',
+            preexec_fn=os.setsid
         )
 
     def is_process_running(self):
@@ -42,10 +44,12 @@ class Executor:
 
     def stop(self):
         if self.process is None:
+            logging.info('no process running ... nothing to stop')
             return
-        try:
-            self.process.terminate()
-            out, err = self.process.communicate(timeout=3)
-        except subprocess.TimeoutExpired:
-            self.process.kill()
-            out, err = self.process.communicate()
+
+        logging.info('terminating process')
+
+        os.killpg(os.getpgid(self.process.pid), signal.SIGTERM)
+
+        self.process.terminate()
+        out, err = self.process.communicate(timeout=3)
